OC.L10N.register(
    "user_ldap",
    {
    "Users" : "Benotzer",
    "Groups" : "Gruppen",
    "Help" : "Hëllef",
    "Host" : "Host",
    "Password" : "Passwuert",
    "Back" : "Zeréck",
    "Continue" : "Weider",
    "Advanced" : "Avancéiert"
},
"nplurals=2; plural=(n != 1);");
